---
name: Help wanted
about: If you have some issues with configuration
title: "[HELP]"
labels: help wanted
assignees: zbeacon

---

**Describe the issue**
Create description about your issue, and your actions to solve it.


**Configuration** (Attach your configuration file)
**Notate: Remove Access token from file if you wanna attach tb_gateway.yaml**


**Connector name (If you need help with some connector/converter):**
[e.g. MQTT Connector]


**Error traceback (If it was raised):**
```
'deviceName'
Traceback (most recent call last):
  File "<input>", line 2, in <module>
KeyError: 'deviceName'
```


**Versions (please complete the following information):**
 - OS: [e.g. Ubuntu 18.04]
 - Thingsboard IoT Gateway version [e.g. 2.2.4]
 - Python version[e.g. 3.7]
